@@ -1,5 +1,6 @@
 from .chord import Chord
 from .timepoints import get_notes_by_beat
+from miditoolkit.midi import containers
 
 
 def get_pitch_map(midi_obj):
@@ -211,3 +212,26 @@ class Dechorder:
                     chords.append(two_chord[0])
 
         return chords
+
+    @staticmethod
+    def enchord(midi_obj):
+        interval = midi_obj.ticks_per_beat
+        midi_obj.markers = []
+        chords = Dechorder.dechord(midi_obj)
+        first_chord = chords[0]
+
+        if first_chord.is_complete():
+            chord_marker = containers.Marker(text=first_chord, time=0)
+            midi_obj.markers.append(chord_marker)
+        for i, (prev_chord, next_chord) in enumerate(zip(chords[:-1], chords[1:])):
+            if (prev_chord[0] != next_chord[0] or
+                    prev_chord[1] != next_chord[1] or
+                    prev_chord[2] != next_chord[2]):
+                if next_chord[0] < 0 or next_chord[1] is None:
+                    continue
+                else:
+                    chord_marker = containers.Marker(text=next_chord, time=(i + 1) * interval)
+                    midi_obj.markers.append(chord_marker)
+
+        return midi_obj
+
